package com.sf.service.deployment.service.impl;

import java.util.List;
import com.sf.common.utils.DateUtils;
import com.sf.service.deployment.domain.DeploymentModuleList;
import com.sf.service.deployment.mapper.DeploymentModuleListMapper;
import com.sf.service.deployment.service.IDeploymentModuleListService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * H5模块包Service业务层处理
 * 
 * @author ztzh
 * @date 2024-04-22
 */
@Service
public class DeploymentModuleListServiceImpl implements IDeploymentModuleListService
{
    @Autowired
    private DeploymentModuleListMapper deploymentModuleListMapper;

    /**
     * 查询H5模块包
     * 
     * @param id H5模块包主键
     * @return H5模块包
     */
    @Override
    public DeploymentModuleList selectDeploymentModuleListById(Long id)
    {
        return deploymentModuleListMapper.selectDeploymentModuleListById(id);
    }

    /**
     * 查询H5模块包列表
     * 
     * @param deploymentModuleList H5模块包
     * @return H5模块包
     */
    @Override
    public List<DeploymentModuleList> selectDeploymentModuleListList(DeploymentModuleList deploymentModuleList)
    {
        return deploymentModuleListMapper.selectDeploymentModuleListList(deploymentModuleList);
    }

    /**
     * 新增H5模块包
     * 
     * @param deploymentModuleList H5模块包
     * @return 结果
     */
    @Override
    public int insertDeploymentModuleList(DeploymentModuleList deploymentModuleList)
    {
        deploymentModuleList.setCreateTime(DateUtils.getNowDate());
        return deploymentModuleListMapper.insertDeploymentModuleList(deploymentModuleList);
    }

    /**
     * 修改H5模块包
     * 
     * @param deploymentModuleList H5模块包
     * @return 结果
     */
    @Override
    public int updateDeploymentModuleList(DeploymentModuleList deploymentModuleList)
    {
        deploymentModuleList.setUpdateTime(DateUtils.getNowDate());
        return deploymentModuleListMapper.updateDeploymentModuleList(deploymentModuleList);
    }

    /**
     * 批量删除H5模块包
     * 
     * @param ids 需要删除的H5模块包主键
     * @return 结果
     */
    @Override
    public int deleteDeploymentModuleListByIds(Long[] ids)
    {
        return deploymentModuleListMapper.deleteDeploymentModuleListByIds(ids);
    }

    /**
     * 删除H5模块包信息
     * 
     * @param id H5模块包主键
     * @return 结果
     */
    @Override
    public int deleteDeploymentModuleListById(Long id)
    {
        return deploymentModuleListMapper.deleteDeploymentModuleListById(id);
    }
}
