package com.sf.vertx.handle;

import static com.sf.vertx.constans.SACConstants.CACHE_KEY_CONNECTOR;

import org.apache.commons.lang3.StringUtils;

import com.sf.vertx.api.pojo.ApiConfig;
import com.sf.vertx.api.pojo.AppConfig;
import com.sf.vertx.enums.GatewayError;
import com.sf.vertx.exception.ServiceException;

import io.vertx.ext.web.RoutingContext;
import lombok.extern.slf4j.Slf4j;

@Slf4j
public class SACParameterCheckHandlerImpl extends BaseRoutingContextDataHandler implements ParameterCheckHandler {

	@Override
	public void handle(RoutingContext rc) {
		try {
			log.info("Enter SAC Route");
			// SAC规范要求Header必须要同时包含appCode和apiCode
			String appCode = rc.request().headers().get(AppConfigHandler.getAppCodeHeaderKey());
			String apiCode = rc.request().headers().get(AppConfigHandler.getApiCodeHeaderKey());
			if (StringUtils.isBlank(appCode) || StringUtils.isBlank(apiCode)) {
				rc.fail(new ServiceException(GatewayError.PARAMETER_TRANSFER_ERROR));
				return;
			}
			AppConfig appConfig = AppConfigHandler.getAppConfig(appCode);
			if (appConfig == null) {
				rc.fail(new ServiceException(GatewayError.APP_SERVICE_NOT_FOUND));
				return;
			}
			String apiCacheKey = appConfig.getAppCode() + CACHE_KEY_CONNECTOR + apiCode;
			ApiConfig apiConfig = AppConfigHandler.getApicodeConfig(apiCacheKey);
			if (apiConfig == null) {
				rc.fail(new ServiceException(GatewayError.API_SERVICE_NOT_FOUND));
				return;
			}

			// 设置上下午数据
			this.ctxData(rc, appConfig, apiConfig, apiCacheKey);
		} catch (Exception e) {
			log.error("SACParameterCheckHandlerImpl Error:", e);
			rc.fail(new ServiceException(GatewayError.DEFAULT_SERVICE_ERROR));
			return;
		}
		rc.next();
	}
}
