/*
package com.sf.vertx.handle;

import cn.hutool.core.util.StrUtil;
import com.sf.vertx.enums.GatewayError;
import com.sf.vertx.exception.MockException;
import com.sf.vertx.exception.ServiceException;
import com.sf.vertx.utils.AppUtils;

import io.vertx.core.json.JsonObject;
import io.vertx.ext.web.RoutingContext;
import io.vertx.ext.web.handler.HttpException;
import lombok.extern.slf4j.Slf4j;


@Slf4j
public class RestfulFailureHandlerImpl implements RestfulFailureHandler {

	@Override
	public void handle(RoutingContext frc) {
		int statusCode = 500;
		JsonObject errorJson;
		// 网关的业务码
		int gatewayServiceCode = GatewayError.DEFAULT_SERVICE_ERROR.getCode();
		try {
			Throwable failure = frc.failure();
			log.info("failure:", failure);
			if (failure instanceof HttpException) {
				HttpException httpException = (HttpException) failure;
				gatewayServiceCode = httpException.getStatusCode();
				errorJson = AppUtils.getResponseJsonByGatewayError(GatewayError.getByCode(statusCode));
				if (StrUtil.isNotBlank(httpException.getPayload())){
					errorJson.put("msg",httpException.getPayload());
				}
			} else if (failure instanceof MockException) {
				MockException mockException = (MockException) failure;
				gatewayServiceCode = mockException.getStatusCode();
				statusCode = mockException.getStatusCode();
				errorJson = new JsonObject(mockException.getPayload());
			}else if (failure instanceof ServiceException) {
				ServiceException serviceException = (ServiceException) failure;
				gatewayServiceCode = serviceException.getStatusCode();
				// 业务异常，为网关业务错误，响应码设置为500,
				GatewayError gatewayError = GatewayError.getByCode(serviceException.getStatusCode());
				// 如果是被限流或熔断，直接返回限流或熔断响应
				if (GatewayError.REQUEST_URL_RESTRICTED_BY_FLOW.equals(gatewayError)
				|| GatewayError.REQUEST_URL_IS_BROKEN.equals(gatewayError)){
					errorJson = new JsonObject(serviceException.getPayload());
				}else {
					errorJson = AppUtils.getResponseJsonByGatewayError(gatewayError);
				}
			} else {
				errorJson = AppUtils.getResponseJsonByGatewayError(GatewayError.getByCode(statusCode));
			}

		} catch (Exception e) {
			log.error("RestfulFailureHandlerImpl.handle Error:",e);
			errorJson = AppUtils.getResponseJsonByGatewayError(GatewayError.DEFAULT_SERVICE_ERROR);
		}
		frc.response().setChunked(true).setStatusCode(statusCode).putHeader("Content-Type", "application/json")
				.putHeader(AppConfigHandler.sacResponseHeaderKey(), String.valueOf(gatewayServiceCode))
				.end(errorJson.toBuffer());
	}



}
*/
